[![PyPI version](https://badge.fury.io/py/easys-ordermanager.svg)](https://badge.fury.io/py/easys-ordermanager)
[![Travis CI build status](https://travis-ci.org/RegioHelden/easys-ordermanager.svg)](https://travis-ci.org/RegioHelden/easys-ordermanager)
[![Coverage Status](https://coveralls.io/repos/github/RegioHelden/easys-ordermanager/badge.svg?branch=add_coveralls)](https://coveralls.io/github/RegioHelden/easys-ordermanager?branch=add_coveralls)

# EasyS order manager API
